gs_quant.timeseries.technicals.relative_strength_index — gs_quant 0.1 documentation

# gs_quant.timeseries.technicals.relative_strength_index

`relative_strength_index`(x, w=14)

  Relative Strength Index

  Parameters

    - x (`Series`) – time series of prices

    - w (`Union`[`Window`, `int`, `str`]) – Window or int: size of window and ramp up to use. e.g. Window(22, 10) where 22 is the window size and 10 the ramp up value. If w is a string, it should be a relative date like ‘1m’, ‘1d’, etc. Window size defaults to length of series.

  Return type

    `DataFrame`

  Returns

    date-based time series of RSI

  Usage

  The RSI computes momentum as the ratio of higher closes to lower closes: stocks which have had more or stronger positive changes have a higher RSI than stocks which have had more or stronger negative changes.

  See RSI for more information

  Examples

  Compute relative strength index over a \(14\) day window:

      >>> prices = generate_series(100)
      >>> relative_strength_index(prices, 14)

  See also

  `moving_average()` `std()` `smoothed_moving_average()`